@@ -1,4 +1,4 @@
-"""Qpid Transport.
+"""Qpid Transport module for kombu.
 
 `Qpid`_ transport using `qpid-python`_ as the client and `qpid-tools`_ for
 broker management.
@@ -27,6 +27,15 @@ or to install the requirements manually:
 .. _`qpid-python`: https://pypi.org/project/qpid-python/
 .. _`qpid-tools`: https://pypi.org/project/qpid-tools/
 
+Features
+========
+* Type: Native
+* Supports Direct: Yes
+* Supports Topic: Yes
+* Supports Fanout: Yes
+* Supports Priority: Yes
+* Supports TTL: Yes
+
 Authentication
 ==============
 
@@ -76,34 +85,35 @@ options override and replace any other default or specified values. If using
 Celery, this can be accomplished by setting the
 *BROKER_TRANSPORT_OPTIONS* Celery option.
 """
-from __future__ import absolute_import, unicode_literals
 
-from collections import OrderedDict
+from __future__ import annotations
+
 import os
 import select
 import socket
 import ssl
 import sys
 import uuid
-
 from gettext import gettext as _
+from queue import Empty
+from time import monotonic
 
 import amqp.protocol
 
 try:
     import fcntl
 except ImportError:
-    fcntl = None  # noqa
+    fcntl = None
 
 try:
     import qpidtoollibs
 except ImportError:  # pragma: no cover
-    qpidtoollibs = None     # noqa
+    qpidtoollibs = None
 
 try:
-    from qpid.messaging.exceptions import ConnectionError, NotFound
+    from qpid.messaging.exceptions import ConnectionError
     from qpid.messaging.exceptions import Empty as QpidEmpty
-    from qpid.messaging.exceptions import SessionClosed
+    from qpid.messaging.exceptions import NotFound, SessionClosed
 except ImportError:  # pragma: no cover
     ConnectionError = None
     NotFound = None
@@ -115,15 +125,16 @@ try:
 except ImportError:  # pragma: no cover
     qpid = None
 
-
-from kombu.five import Empty, items, monotonic, PY3
 from kombu.log import get_logger
-from kombu.transport.virtual import Base64, Message
 from kombu.transport import base, virtual
-
+from kombu.transport.virtual import Base64, Message
 
 logger = get_logger(__name__)
 
+try:
+    buffer
+except NameError:
+    buffer = bytes
 
 OBJECT_ALREADY_EXISTS_STRING = 'object already exists'
 
@@ -148,7 +159,7 @@ class AuthenticationFailure(Exception):
     """Cannot authenticate with Qpid."""
 
 
-class QoS(object):
+class QoS:
     """A helper object for message prefetch and ACKing purposes.
 
     :keyword prefetch_count: Initial prefetch count, hard set to 1.
@@ -179,7 +190,7 @@ class QoS(object):
     def __init__(self, session, prefetch_count=1):
         self.session = session
         self.prefetch_count = 1
-        self._not_yet_acked = OrderedDict()
+        self._not_yet_acked = {}
 
     def can_consume(self):
         """Return True if the :class:`Channel` can consume more messages.
@@ -219,8 +230,8 @@ class QoS(object):
         """Append message to the list of un-ACKed messages.
 
         Add a message, referenced by the delivery_tag, for ACKing,
-        rejecting, or getting later. Messages are saved into an
-        :class:`collections.OrderedDict` by delivery_tag.
+        rejecting, or getting later. Messages are saved into a
+        dict by delivery_tag.
 
         :param message: A received message that has not yet been ACKed.
         :type message: qpid.messaging.Message
@@ -465,12 +476,12 @@ class Channel(base.StdChannel):
 
         """
         if not exchange:
-            address = '%s; {assert: always, node: {type: queue}}' % (
-                routing_key,)
+            address = f'{routing_key}; ' \
+                      '{{assert: always, node: {{type: queue}}}}'
             msg_subject = None
         else:
-            address = '%s/%s; {assert: always, node: {type: topic}}' % (
-                exchange, routing_key)
+            address = f'{exchange}/{routing_key}; '\
+                      '{{assert: always, node: {{type: topic}}}}'
             msg_subject = str(routing_key)
         sender = self.transport.session.sender(address)
         qpid_message = qpid.messaging.Message(content=message,
@@ -517,7 +528,7 @@ class Channel(base.StdChannel):
         """
         queue_to_purge = self._broker.getQueue(queue)
         if queue_to_purge is None:
-            error_text = "NOT_FOUND - no queue '{0}'".format(queue)
+            error_text = f"NOT_FOUND - no queue '{queue}'"
             raise NotFound(code=404, text=error_text)
         message_count = queue_to_purge.values['msgDepth']
         if message_count > 0:
@@ -1123,7 +1134,6 @@ class Channel(base.StdChannel):
         message['body'], body_encoding = self.encode_body(
             message['body'], self.body_encoding,
         )
-        message['body'] = buffer(message['body'])
         props = message['properties']
         props.update(
             body_encoding=body_encoding,
@@ -1212,7 +1222,7 @@ class Channel(base.StdChannel):
             return default
 
 
-class Connection(object):
+class Connection:
     """Qpid Connection.
 
     Encapsulate a connection object for the
@@ -1436,7 +1446,7 @@ class Transport(base.Transport):
 
     def __init__(self, *args, **kwargs):
         self.verify_runtime_environment()
-        super(Transport, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.use_async_interface = False
 
     def verify_runtime_environment(self):
@@ -1454,17 +1464,6 @@ class Transport(base.Transport):
         :raises: RuntimeError if the runtime environment is not acceptable.
 
         """
-        if getattr(sys, 'pypy_version_info', None):
-            raise RuntimeError(
-                'The Qpid transport for Kombu does not '
-                'support PyPy. Try using Python 2.6+',
-            )
-        if PY3:
-            raise RuntimeError(
-                'The Qpid transport for Kombu does not '
-                'support Python 3. Try using Python 2.6+',
-            )
-
         if dependency_is_none(qpidtoollibs):
             raise RuntimeError(
                 'The Python package "qpidtoollibs" is missing. Install it '
@@ -1595,7 +1594,7 @@ class Transport(base.Transport):
 
         """
         conninfo = self.client
-        for name, default_value in items(self.default_connection_params):
+        for name, default_value in self.default_connection_params.items():
             if not getattr(conninfo, name, None):
                 setattr(conninfo, name, default_value)
         if conninfo.ssl:
