@@ -89,6 +89,26 @@ class test_ConsumerMixin:
         c.connection.drain_events.side_effect = se
         with pytest.raises(socket.error):
             next(it)
+        c.connection.heartbeat_check.assert_called()
+
+    def test_consume_drain_heartbeat_check_no_timeout(self):
+        c, Acons, Bcons = self._context()
+        c.should_stop = False
+        it = c.consume(no_ack=True, timeout=None)
+
+        def se(*args, **kwargs):
+            c.should_stop = True
+            raise socket.timeout()
+        c.connection.drain_events.side_effect = se
+        with pytest.raises(StopIteration):
+            next(it)
+        c.connection.heartbeat_check.assert_called()
+
+        it = c.consume(no_ack=True, timeout=0)
+        c.connection.drain_events.side_effect = se
+        with pytest.raises(StopIteration):
+            next(it)
+        c.connection.heartbeat_check.assert_called()
 
     def test_Consumer_context(self):
         c, Acons, Bcons = self._context()
@@ -110,7 +130,7 @@ class test_ConsumerMixin:
 
 class test_ConsumerMixin_interface:
 
-    def setup(self):
+    def setup_method(self):
         self.c = ConsumerMixin()
 
     def test_get_consumers(self):
