@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import socket
 
 import pytest
@@ -7,7 +9,7 @@ from kombu import Connection, Consumer, Exchange, Producer, Queue
 
 class test_MemoryTransport:
 
-    def setup(self):
+    def setup_method(self):
         self.c = Connection(transport='memory')
         self.e = Exchange('test_transport_memory')
         self.q = Queue('test_transport_memory',
@@ -131,8 +133,8 @@ class test_MemoryTransport:
         with pytest.raises(socket.timeout):
             self.c.drain_events(timeout=0.1)
 
-        del(c1)  # so pyflakes doesn't complain.
-        del(c2)
+        del c1  # so pyflakes doesn't complain.
+        del c2
 
     def test_drain_events_unregistered_queue(self):
         c1 = self.c.channel()
